==> opennms-webapp-1.7.3-sources.jar: org/opennms/web/notification/WebNotificationRepository.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.web.notification;

import java.util.Date;

import org.opennms.web.notification.filter.NotificationCriteria;

public interface WebNotificationRepository {
    
    public abstract int countMatchingNotifications(NotificationCriteria criteria);
    
    public abstract Notification getNotification(int noticeId);
    
    public abstract Notification[] getMatchingNotifications(NotificationCriteria criteria);
    
    public abstract void acknowledgeMatchingNotification(String user, Date timestamp, NotificationCriteria criteria);
}

==> opennms-webapp-1.9.5-sources.jar: org/opennms/web/notification/WebNotificationRepository.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.web.notification;

import java.util.Date;

import org.opennms.web.notification.filter.NotificationCriteria;

/**
 * <p>WebNotificationRepository interface.</p>
 *
 * @author ranger
 * @version $Id: $
 * @since 1.8.1
 */
public interface WebNotificationRepository {
    
    /**
     * <p>countMatchingNotifications</p>
     *
     * @param criteria a {@link org.opennms.web.notification.filter.NotificationCriteria} object.
     * @return a int.
     */
    public abstract int countMatchingNotifications(NotificationCriteria criteria);
    
    /**
     * <p>getNotification</p>
     *
     * @param noticeId a int.
     * @return a {@link org.opennms.web.notification.Notification} object.
     */
    public abstract Notification getNotification(int noticeId);
    
    /**
     * <p>getMatchingNotifications</p>
     *
     * @param criteria a {@link org.opennms.web.notification.filter.NotificationCriteria} object.
     * @return an array of {@link org.opennms.web.notification.Notification} objects.
     */
    public abstract Notification[] getMatchingNotifications(NotificationCriteria criteria);
    
    /**
     * <p>acknowledgeMatchingNotification</p>
     *
     * @param user a {@link java.lang.String} object.
     * @param timestamp a java$util$Date object.
     * @param criteria a {@link org.opennms.web.notification.filter.NotificationCriteria} object.
     */
    public abstract void acknowledgeMatchingNotification(String user, Date timestamp, NotificationCriteria criteria);
}
